# v0.27.x series (next stable)

## v0.27.0 (upcoming release)

### Deprecated

* ⚠️ Specifying the spectral range for atmospheric absorption database
  configuration is no longer required. The previous behaviour is removed and
  the corresponding interface is deprecated.

### Removed

* ⚠️ Specifying atmospheric absorption databases using loaded data is no longer
  supported. Instead, instantiate an {class}`.AbsorptionDatabase` object.

### Added

* Introduced a new {class}`.AbsorptionDatabase` abstraction in charge of
  managing atmospheric molecular absorption data ({ghpr}`397`).
* Eradiate can now be configured using TOML files ({ghpr}`397`).
* The `eradiate data fetch` command-line interface now accepts keywords to
  facilitate absorption database downloads ({ghpr}`397`).
* Gaussian SRF datasets can now be dynamically generated using the
  :func:`.srf_tools.make_gaussian` function ({ghpr}`401`).
* All `.Shape` classes now support a `to_world` member, which defines an arbitrary
  transformation of the object.

### Changed

* ⚠️ Most settings are now accessed through the :attr:`.settings` mapping
  ({ghpr}`397`).

### Fixed

* Large absorption databases are now handled with little to no performance
  penalty ({ghpr}`397`).

### Internal changes

* 🖥️ Settings are now powered by the Dynaconf library ({ghpr}`397`).
* 🖥️ Renamed and refactored atmosphere fixtures for performance and clarity
  ({ghpr}`397`).
